Learn R Programming

ChIPpeakAnno (version 2.16.4)

TSS.human.GRCh37: TSS annotation for human sapiens (GRCh37) obtained from biomaRt

Description

TSS annotation for human sapiens (GRCh37) obtained from biomaRt

Usage

data(TSS.human.GRCh37)

Arguments

Format

RangedData with slot start holding the start position of the gene, slot end holding the end position of the gene, slot rownames holding ensembl gene id and slot space holding the chromosome location where the gene is located. In addition, the following variables are included.
strand
1 for positive strand and -1 for negative strand
description
description of the gene

Details

used in the examples Annotation data obtained by:

mart = useMart(biomart = "ensembl", dataset = "hsapiens_gene_ensembl") getAnnotation(mart, featureType = "TSS")

References

Examples

Run this code
data(TSS.human.GRCh37)
slotNames(TSS.human.GRCh37)

Run the code above in your browser using DataLab